from setuptools import setup

setup(name='postolit',
      version='0.0',
      description='Postoperative Library for Image Transformation',
      packages=['postolit'],
      author_email='anat_post@mail.ru',
      zip_safe=False)
